==> haskell-persistent-sqlite-2.13.1.0-235-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-sqlite.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   persistent-sqlite
version:                2.13.1.0
visibility:             public
id:                     persistent-sqlite-2.13.1.0-IDvEHlXFMGc54zabztc8zE
key:                    persistent-sqlite-2.13.1.0-IDvEHlXFMGc54zabztc8zE
license:                MIT
maintainer:             Michael Snoyman <michael@snoyman.com>
author:                 Michael Snoyman <michael@snoyman.com>
stability:              Stable
homepage:               http://www.yesodweb.com/book/persistent
synopsis:               Backend for the persistent library using sqlite3.
description:
    This package includes a thin sqlite3 wrapper based on the direct-sqlite package, as well as the entire C library, so there are no system dependencies.

category:               Database, Yesod
abi:                    ccdf4894c19eefe495cc70f087934ad9
exposed:                True
exposed-modules:
    Database.Persist.Sqlite Database.Sqlite Database.Sqlite.Internal

import-dirs:            /usr/lib/ghc-9.4.8/site-local/persistent-sqlite-2.13.1.0
library-dirs:           /usr/lib/ghc-9.4.8/site-local/persistent-sqlite-2.13.1.0
library-dirs-static:    /usr/lib/ghc-9.4.8/site-local/persistent-sqlite-2.13.1.0
dynamic-library-dirs:   /usr/lib
data-dir:               /usr/share/haskell-persistent-sqlite
hs-libraries:           HSpersistent-sqlite-2.13.1.0-IDvEHlXFMGc54zabztc8zE
extra-libraries:        pthread sqlite3
extra-libraries-static: sqlite3 m z
depends:
    aeson-2.1.2.1-LRjlcarryWV47QfBrWIlNe base-4.17.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-LsCA1bXaHAtCkLdZq4D2B7
    containers-0.6.7 microlens-th-0.4.3.17-Vfga0HXPTS6SXD3NuXqZ3
    monad-logger-0.3.42-28haxcqRa1n1Yms9If3yr8 mtl-2.2.2
    persistent-2.14.5.1-L2OPY2bK5ImHD1npFBLlSb
    resource-pool-0.2.3.2-H5U1I0DuM1CCOytzzp3F55
    resourcet-1.2.6-5T1JOIBomjw5njJplll3VQ text-2.0.2 time-1.12.2
    transformers-0.5.6.2 unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    unordered-containers-0.2.20-66FGtARgHXEQRH0VfdDtx

haddock-interfaces:
    /usr/share/doc/haskell-persistent-sqlite/html/persistent-sqlite.haddock

haddock-html:           /usr/share/doc/haskell-persistent-sqlite/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-sqlite-2.13.1.0-236-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-sqlite.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   persistent-sqlite
version:                2.13.1.0
visibility:             public
id:                     persistent-sqlite-2.13.1.0-Kos4kQpQfcpIANLg8cjzg8
key:                    persistent-sqlite-2.13.1.0-Kos4kQpQfcpIANLg8cjzg8
license:                MIT
maintainer:             Michael Snoyman <michael@snoyman.com>
author:                 Michael Snoyman <michael@snoyman.com>
stability:              Stable
homepage:               http://www.yesodweb.com/book/persistent
synopsis:               Backend for the persistent library using sqlite3.
description:
    This package includes a thin sqlite3 wrapper based on the direct-sqlite package, as well as the entire C library, so there are no system dependencies.

category:               Database, Yesod
abi:                    0d8cc817093713cd2ae5d34535a04557
exposed:                True
exposed-modules:
    Database.Persist.Sqlite Database.Sqlite Database.Sqlite.Internal

import-dirs:            /usr/lib/ghc-9.4.8/site-local/persistent-sqlite-2.13.1.0
library-dirs:           /usr/lib/ghc-9.4.8/site-local/persistent-sqlite-2.13.1.0
library-dirs-static:    /usr/lib/ghc-9.4.8/site-local/persistent-sqlite-2.13.1.0
dynamic-library-dirs:   /usr/lib
data-dir:               /usr/share/haskell-persistent-sqlite
hs-libraries:           HSpersistent-sqlite-2.13.1.0-Kos4kQpQfcpIANLg8cjzg8
extra-libraries:        pthread sqlite3
extra-libraries-static: sqlite3 m z
depends:
    aeson-2.1.2.1-EZ4q40CmD1e6rYIqwxbubT base-4.17.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-HPPRf3ag9AHz93zM59Qo5
    containers-0.6.7 microlens-th-0.4.3.17-Vfga0HXPTS6SXD3NuXqZ3
    monad-logger-0.3.42-JWlG3jsptqTJ4PZcRq7x8y mtl-2.2.2
    persistent-2.14.5.1-23871TT3KeiHANePCXjuAr
    resource-pool-0.2.3.2-H5U1I0DuM1CCOytzzp3F55
    resourcet-1.2.6-5T1JOIBomjw5njJplll3VQ text-2.0.2 time-1.12.2
    transformers-0.5.6.2 unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    unordered-containers-0.2.20-Kq2dPHqifzB9n0MYGmTosg

haddock-interfaces:
    /usr/share/doc/haskell-persistent-sqlite/html/persistent-sqlite.haddock

haddock-html:           /usr/share/doc/haskell-persistent-sqlite/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
